# Installing

You can install using pip:

`pip install handcalcs`

A conda-forge installation is coming soon.

## Dependencies

* pyparsing
* more-itertools
* innerscope
* nbconvert

While not a true "dependency", currently handcalcs installs nbconvert 5.6.1 to enable simple rendering of Jupyter Notebooks to PDF via the browser. In nbconvert 6.x, the templating system was changed and handcalcs does not yet support the new template system. 

handcalcs intends to support nbconvert 6.x in the future.



